<!-- Generated by documentation.js. Update this documentation by updating the source code. -->

## react/general

### rules

#### react/boolean-prop-naming

Enforces consistent naming for boolean props.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/boolean-prop-naming.md][1]

##### Examples

```javascript
["error", {
 propTypeNames: ["bool"],
 rule: "^(is|has)[A-Z([A-Za-z0-9]?)+",
}]
```

#### react/button-has-type

Forbid "button" element without an explicit "type" attribute.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/button-has-type.md][2]

##### Examples

```javascript
["error", {
 button: true,
 submit: true,
 reset: true,
}]
```

#### react/default-props-match-prop-types

Prevent extraneous defaultProps on components.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/default-props-match-prop-types.md][3]

##### Examples

```javascript
["error", {
 allowRequiredDefaults: false,
}]
```

#### react/destructuring-assignment

Enforces consistent usage of destructuring assignment in component.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/destructuring-assignment.md][4]

##### Examples

```javascript
["error", "always", {
 ignoreClassFields: true,
}]
```

#### react/display-name

Prevent missing displayName in a React component definition.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/display-name.md][5]

##### Examples

```javascript
["error", {
 ignoreTranspilerName: false,
}]
```

#### react/forbid-component-props

Forbid certain props on Components.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/forbid-component-props.md][6]

##### Examples

```javascript
["error", {
 forbid: ["className", "style"],
}]
```

#### react/forbid-dom-props

Forbid certain props on DOM Nodes.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/forbid-dom-props.md][7]

##### Examples

```javascript
["error", {
 forbid: [],
}]
```

#### react/forbid-elements

Forbid certain elements.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/forbid-elements.md][8]

##### Examples

```javascript
["error", {
 forbid: [],
}]
```

#### react/forbid-prop-types

Forbid certain propTypes.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/forbid-prop-types.md][9]

##### Examples

```javascript
["error", {
 forbid: ["any", "array", "object"],
 checkContextTypes: false,
 checkChildContextTypes: false,
}]
```

#### react/forbid-foreign-prop-types

Forbid foreign propTypes.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/forbid-foreign-prop-types.md][10]

##### Examples

```javascript
"error"
```

#### react/no-access-state-in-setstate

Prevent using this.state inside this.setState.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/no-access-state-in-setstate.md][11]

##### Examples

```javascript
"error"
```

#### react/no-array-index-key

Prevent using Array index in key props.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/no-array-index-key.md][12]

##### Examples

```javascript
"error"
```

#### react/no-children-prop

Prevent passing children as props.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/no-children-prop.md][13]

##### Examples

```javascript
"error"
```

#### react/no-danger

Prevent usage of dangerous JSX properties.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/no-danger.md][14]

##### Examples

```javascript
"error"
```

#### react/no-danger-with-children

Prevent problem with children and props.dangerouslySetInnerHTML.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/no-danger-with-children.md][15]

##### Examples

```javascript
"error"
```

#### react/no-deprecated

Prevent usage of deprecated methods, including component lifecyle
methods.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/no-deprecated.md][16]

##### Examples

```javascript
"error"
```

#### react/no-did-mount-set-state

Prevent usage of setState in componentDidMount.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/no-did-mount-set-state.md][17]

##### Examples

```javascript
["error", "disallow-in-func"]
```

#### react/no-did-update-set-state

Prevent usage of setState in componentDidUpdate.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/no-did-update-set-state.md][18]

##### Examples

```javascript
["error", "disallow-in-func"]
```

#### react/no-direct-mutation-state

Prevent direct mutation of this.state.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/no-direct-mutation-state.md][19]

##### Examples

```javascript
"error"
```

#### react/no-find-dom-node

Prevent usage of findDOMNode.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/no-find-dom-node.md][20]

##### Examples

```javascript
"error"
```

#### react/no-is-mounted

Prevent usage of isMounted.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/no-is-mounted.md][21]

##### Examples

```javascript
"error"
```

#### react/no-multi-comp

Prevent multiple component definition per file.

NOTES:

-   In tets, we often have multuple components declared in one file. As a
    result, it might be better to disable this rule. For now, we will
    throw an error if there are more than one Class components in a file.
    If we have multiple stateless functions, it will ignore them.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/no-multi-comp.md][22]

##### Examples

```javascript
["error", {
 ignoreStateless: true,
}]
```

#### react/no-redundant-should-component-update

Prevent usage of shouldComponentUpdate when extending
React.PureComponent.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/no-redundant-should-component-update.md][23]

##### Examples

```javascript
"error"
```

#### react/no-render-return-value

Prevent usage of the return value of React.render.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/no-render-return-value.md][24]

##### Examples

```javascript
"error"
```

#### react/no-set-state

Prevent usage of setState.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/no-set-state.md][25]

##### Examples

```javascript
"error"
```

#### react/no-typos

Prevent common casing typos.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/no-typos.md][26]

##### Examples

```javascript
"error"
```

#### react/no-string-refs

Prevent using string references in ref attribute.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/no-string-refs.md][27]

##### Examples

```javascript
["error", {
 noTemplateLiterals: true,
}]
```

#### react/no-this-in-sfc

Prevent using this in stateless functional components.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/no-this-in-sfc.md][28]

##### Examples

```javascript
"error"
```

#### react/no-unescaped-entities

Prevent invalid characters from appearing in markup.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/no-unescaped-entities.md][29]

##### Examples

```javascript
["error", {
 forbid: [">", '"', "\'", "}"],
}]
```

#### react/no-unknown-property

Prevent usage of unknown DOM property. (fixable)

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/no-unknown-property.md][30]

##### Examples

```javascript
["error", {
 ignore: [],
}]
```

#### react/no-unsafe

Prevent usage of unsafe lifecycle methods

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/no-unsafe.md][31]

##### Examples

```javascript
["error", {
 checkAliases: true,
}]
```

#### react/no-unused-prop-types

Prevent definitions of unused prop types.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/no-unused-prop-types.md][32]

##### Examples

```javascript
["error", {
 customValidators: [],
 skipShapeProps: true,
}]
```

#### react/no-unused-state

Prevent definitions of unused state properties.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/no-unused-state.md][33]

##### Examples

```javascript
"error"
```

#### react/no-will-update-set-state

Prevent usage of setState in componentWillUpdate.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/no-will-update-set-state.md][34]

##### Examples

```javascript
["error", "disallow-in-func"]
```

#### react/prefer-es6-class

Enforce ES5 or ES6 class for React Components.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/prefer-es6-class.md][35]

##### Examples

```javascript
["error", "always"]
```

#### react/prefer-read-only-props

Enforce that props are read-only.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/prefer-read-only-props.md][36]

##### Examples

```javascript
"error"
```

#### react/prefer-stateless-function

Enforce stateless React Components to be written as a pure function.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/prefer-stateless-function.md][37]

##### Examples

```javascript
["error", {
 ignorePureComponents: true,
}]
```

#### react/prop-types

Prevent missing props validation in a React component definition.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/prop-types.md][38]

##### Examples

```javascript
["error", {
 ignore: [],
 customValidators: [],
 skipUndeclared: true,
}]
```

#### react/react-in-jsx-scope

Prevent missing React when using JSX.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/react-in-jsx-scope.md][39]

##### Examples

```javascript
"error"
```

#### react/require-default-props

Enforce a defaultProps definition for every prop that is not a required
prop.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/require-default-props.md][40]

##### Examples

```javascript
["error", {
 forbidDefaultForRequired: true,
}]
```

#### react/require-optimization

Enforce React components to have a shouldComponentUpdate method.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/require-optimization.md][41]

##### Examples

```javascript
"off"
```

#### react/require-render-return

Enforce ES5 or ES6 class for returning value in render function.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/require-render-return.md][42]

##### Examples

```javascript
"error"
```

#### react/self-closing-comp

Prevent extra closing tags for components without children. (fixable)

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/self-closing-comp.md][43]

##### Examples

```javascript
["error", {
 component: true,
 html: true,
}]
```

#### react/sort-comp

Enforce component methods order.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/sort-comp.md][44]

##### Examples

```javascript
["error", {
  order: [
    "static-methods",
    "instance-variables",
    "lifecycle",
    "/^on.+$/",
    "getters",
    "setters",
    "/^(get|set)(?!(InitialState$|DefaultProps$|ChildContext$)).+$/",
    "instance-methods",
    "everything-else",
    "rendering",
  ],
  groups: {
    "lifecycle": [
      'displayName',
      'propTypes',
      'contextTypes',
      'childContextTypes',
      'mixins',
      'statics',
      'defaultProps',
      'constructor',
      'getDefaultProps',
      'getInitialState',
      'state',
      'getChildContext',
      'getDerivedStateFromProps',
      'componentWillMount',
      'UNSAFE_componentWillMount',
      'componentDidMount',
      'componentWillReceiveProps',
      'UNSAFE_componentWillReceiveProps',
      'shouldComponentUpdate',
      'componentWillUpdate',
      'UNSAFE_componentWillUpdate',
      'getSnapshotBeforeUpdate',
      'componentDidUpdate',
      'componentDidCatch',
      'componentWillUnmount'
    ],
    rendering: [
      "/^render.+$/",
      "render"
    ]
  }
}]
```

#### react/sort-prop-types

Enforce propTypes declarations alphabetical sorting.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/sort-prop-types.md][45]

##### Examples

```javascript
["off", {
 callbacksLast: true,
 ignoreCase: false,
 requiredFirst: true,
 sortShapeProp: true,
 noSortAlphabetically: false,
}]
```

#### react/state-in-constructor

Enforce the state initialization style to be either in a constructor or
with a class property.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/state-in-constructor.md][46]

##### Examples

```javascript
["error", "never"]
```

#### react/static-property-placement

Enforces where React component static properties should be positioned.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/static-property-placement.md][47]

##### Examples

```javascript
["error", "property assignment"]
```

#### react/style-prop-object

Enforce style prop value being an object.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/style-prop-object.md][48]

##### Examples

```javascript
"error"
```

#### react/void-dom-elements-no-children

Prevent void DOM elements (e.g. <img />, <br />) from receiving children.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/void-dom-elements-no-children.md][49]

##### Examples

```javascript
"error"
```

## react/jsx

### rules

#### react/jsx-boolean-value

Enforce boolean attributes notation in JSX. (fixable)

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-boolean-value.md][50]

##### Examples

```javascript
"off"
```

#### react/jsx-child-element-spacing

Enforce or disallow spaces inside of curly braces in JSX attributes and expressions.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-child-element-spacing.md][51]

##### Examples

```javascript
"off"
```

#### react/jsx-closing-bracket-location

Validate closing bracket location in JSX. (fixable)

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-closing-bracket-location.md][52]

##### Examples

```javascript
["error", {
 nonEmpty: "after-props",
 selfClosing: "tag-aligned",
}]
```

#### react/jsx-closing-tag-location

Validate closing tag location in JSX. (fixable)

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-closing-tag-location.md][53]

##### Examples

```javascript
"error"
```

#### react/jsx-curly-spacing

Enforce or disallow spaces inside of curly braces in JSX attributes and expressions. (fixable)

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-curly-spacing.md][54]

##### Examples

```javascript
["error", {
 when: "never",
 allowMultiline: true,
}]
```

#### react/jsx-equals-spacing

Enforce or disallow spaces around equal signs in JSX attributes. (fixable)

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-equals-spacing.md][55]

##### Examples

```javascript
["error", "never"]
```

#### react/jsx-filename-extension

Restrict file extensions that may contain JSX.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-filename-extension.md][56]

##### Examples

```javascript
["warn", {
 extensions: [".js", ".jsx"],
}]
```

#### react/jsx-first-prop-new-line

Enforce position of the first prop in JSX. (fixable)

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-first-prop-new-line.md][57]

##### Examples

```javascript
["error", "multiline"]
```

#### react/jsx-handler-names

Enforce event handler naming conventions in JSX.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-handler-names.md][58]

##### Examples

```javascript
["error", {
 eventHandlerPrefix: "handle",
 eventHandlerPropPrefix: "on",
}]
```

#### react/jsx-indent

Validate JSX indentation. (fixable)

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-indent.md][59]

##### Examples

```javascript
["error", 2, {
 checkAttributes: true,
 indentLogicalExpressions: true,
}]
```

#### react/jsx-indent-props

Validate props indentation in JSX. (fixable)

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-indent-props.md][60]

##### Examples

```javascript
["error", "first"]
```

#### react/jsx-key

Validate JSX has key prop when in array or iterator.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-key.md][61]

##### Examples

```javascript
"error"
```

#### react/jsx-max-depth

Validate JSX maximum depth.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-max-depth.md][62]

##### Examples

```javascript
["error", {
 max: 10,
}]
```

#### react/jsx-max-props-per-line

Limit maximum of props on a single line in JSX. (fixable)

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-max-props-per-line.md][63]

##### Examples

```javascript
["error", {
 when: "multiline",
}]
```

#### react/jsx-no-bind

Prevent usage of .bind() and arrow functions in JSX props.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-no-bind.md][64]

##### Examples

```javascript
["error", {
 ignoreDOMComponents: false,
 ignoreRefs: false,
 allowArrowFunctions: true,
 allowFunctions: false,
 allowBind: false,
}]
```

#### react/jsx-no-comment-textnodes

Prevent comments from being inserted as text nodes.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-no-comment-textnodes.md][65]

##### Examples

```javascript
"error"
```

#### react/jsx-no-duplicate-props

Prevent duplicate props in JSX.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-no-duplicate-props.md][66]

##### Examples

```javascript
["error", {
 ignoreCase: true,
}]
```

#### react/jsx-no-literals

Prevent usage of unwrapped JSX strings.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-no-literals.md][67]

##### Examples

```javascript
["off", {
 noStrings: false,
}]
```

#### react/jsx-no-target-blank

Prevent usage of unsafe target='\_blank'.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-no-target-blank.md][68]

##### Examples

```javascript
["error", {
 enforceDynamicLinks: "always",
}]
```

#### react/jsx-no-undef

Disallow undeclared variables in JSX.

NOTES:

-   We might want this be true.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-no-undef.md][69]

##### Examples

```javascript
["error", {
 allowGlobals: false
}]
```

#### react/jsx-one-expression-per-line

Limit to one expression per line in JSX.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-one-expression-per-line.md][70]

##### Examples

```javascript
["error", {
 allow: "single-child",
}]
```

#### react/jsx-curly-brace-presence

Enforce curly braces or disallow unnecessary curly braces in JSX.

NOTES:

-   We might want to change this for children.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-curly-brace-presence.md][71]

##### Examples

```javascript
["error", {
 props: "always",
 children: "never",
}]
```

#### react/jsx-fragments

Enforce shorthand or standard form for React fragments.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-fragments.md][72]

##### Examples

```javascript
["error", "element"]
```

#### react/jsx-pascal-case

Enforce PascalCase for user-defined JSX components.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-pascal-case.md][73]

##### Examples

```javascript
["error", {
 allowAllCaps: false,
 ignore: []
}]
```

#### react/jsx-props-no-multi-spaces

Disallow multiple spaces between inline JSX props. (fixable)

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-props-no-multi-spaces.md][74]

##### Examples

```javascript
"error"
```

#### react/jsx-props-no-spreading

Disallow JSX props spreading.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-props-no-spreading.md][75]

##### Examples

```javascript
"off"
```

#### react/jsx-sort-default-props

Enforce default props alphabetical sorting.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-sort-default-props.md][76]

##### Examples

```javascript
["off", {
 ignoreCase: true,
}]
```

#### react/jsx-sort-props

Enforce props alphabetical sorting. (fixable)

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-sort-props.md][77]

##### Examples

```javascript
["off", {
 callbacksLast: true,
 shorthandFirst: true,
 shorthandLast: false,
 ignoreCase: true,
 noSortAlphabetically: true,
 reservedFirst: true,
}]
```

#### react/jsx-tag-spacing

Validate whitespace in and around the JSX opening and closing brackets.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-tag-spacing.md][78]

##### Examples

```javascript
["error", {
 closingSlash: "never",
 beforeSelfClosing: "always",
 afterOpening: "never",
 beforeClosing: "never",
}]
```

#### react/jsx-uses-react

Prevent React to be incorrectly marked as unused.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-uses-react.md][79]

##### Examples

```javascript
"error"
```

#### react/jsx-uses-vars

Prevent variables used in JSX to be incorrectly marked as unused.

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-uses-vars.md][80]

##### Examples

```javascript
"error"
```

#### react/jsx-wrap-multilines

Prevent missing parentheses around multilines JSX. (fixable)

[https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-wrap-multilines.md][81]

##### Examples

```javascript
["error", {
 declaration: "parens-new-line",
 assignment: "parens-new-line",
 return: "parens-new-line",
 arrow: "parens-new-line",
 condition: "parens-new-line",
 logical: "parens-new-line",
 prop: "parens-new-line",
}]
```

[1]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/boolean-prop-naming.md

[2]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/button-has-type.md

[3]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/default-props-match-prop-types.md

[4]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/destructuring-assignment.md

[5]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/display-name.md

[6]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/forbid-component-props.md

[7]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/forbid-dom-props.md

[8]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/forbid-elements.md

[9]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/forbid-prop-types.md

[10]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/forbid-foreign-prop-types.md

[11]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/no-access-state-in-setstate.md

[12]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/no-array-index-key.md

[13]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/no-children-prop.md

[14]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/no-danger.md

[15]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/no-danger-with-children.md

[16]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/no-deprecated.md

[17]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/no-did-mount-set-state.md

[18]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/no-did-update-set-state.md

[19]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/no-direct-mutation-state.md

[20]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/no-find-dom-node.md

[21]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/no-is-mounted.md

[22]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/no-multi-comp.md

[23]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/no-redundant-should-component-update.md

[24]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/no-render-return-value.md

[25]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/no-set-state.md

[26]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/no-typos.md

[27]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/no-string-refs.md

[28]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/no-this-in-sfc.md

[29]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/no-unescaped-entities.md

[30]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/no-unknown-property.md

[31]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/no-unsafe.md

[32]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/no-unused-prop-types.md

[33]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/no-unused-state.md

[34]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/no-will-update-set-state.md

[35]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/prefer-es6-class.md

[36]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/prefer-read-only-props.md

[37]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/prefer-stateless-function.md

[38]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/prop-types.md

[39]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/react-in-jsx-scope.md

[40]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/require-default-props.md

[41]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/require-optimization.md

[42]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/require-render-return.md

[43]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/self-closing-comp.md

[44]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/sort-comp.md

[45]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/sort-prop-types.md

[46]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/state-in-constructor.md

[47]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/static-property-placement.md

[48]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/style-prop-object.md

[49]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/void-dom-elements-no-children.md

[50]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-boolean-value.md

[51]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-child-element-spacing.md

[52]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-closing-bracket-location.md

[53]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-closing-tag-location.md

[54]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-curly-spacing.md

[55]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-equals-spacing.md

[56]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-filename-extension.md

[57]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-first-prop-new-line.md

[58]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-handler-names.md

[59]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-indent.md

[60]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-indent-props.md

[61]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-key.md

[62]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-max-depth.md

[63]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-max-props-per-line.md

[64]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-no-bind.md

[65]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-no-comment-textnodes.md

[66]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-no-duplicate-props.md

[67]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-no-literals.md

[68]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-no-target-blank.md

[69]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-no-undef.md

[70]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-one-expression-per-line.md

[71]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-curly-brace-presence.md

[72]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-fragments.md

[73]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-pascal-case.md

[74]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-props-no-multi-spaces.md

[75]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-props-no-spreading.md

[76]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-sort-default-props.md

[77]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-sort-props.md

[78]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-tag-spacing.md

[79]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-uses-react.md

[80]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-uses-vars.md

[81]: https://github.com/yannickcr/eslint-plugin-react/blob/master/docs/rules/jsx-wrap-multilines.md
